#!/bin/sh

########################################################################
# Copyright (C) 2007-2009 Daniel Balsiger <mail<at>danielbalsiger.ch>  #
#                                                                      #
# This project evolved while my information science project and my     #
# master thesis that followed on.                                      #
#                                                                      #
# Check for latest versions at:                                        #
# https://subversion.cnds.unibe.ch/svn/adam/trunk/image-builder        #
#                                                                      #
# This program is free software; you can redistribute it and/or modify #
# it under the terms of the GNU General Public License version 2 as    #
# published by the Free Software Foundation.                           #
#                                                                      #
########################################################################

. /etc/init.d/rc.functions
. /etc/conf.d/rc.conf

calc_peers()
{
    # generate a new hosts file
    /var/cfengine/bin/gen_etc_hosts.sh

    # null out the peers file
    > ${peersfile}
    
    # more then 5 hops make no sense at the moment
    if [ ${GLOBAL_CFHOPS} -gt 5 ] || [ ${GLOBAL_CFHOPS} -lt 1 ] ; then
        # for traceroute6 HOPS must be >= 2
        GLOBAL_CFHOPS=1
    fi
    hops=${GLOBAL_CFHOPS}
  
    # for traceroute6 HOPS are counted differently
    let hops++

    # loop through peers and traceroute them
    for host in ${networkdir}/*.conf ; do
        . ${host}
        host=${host##*/}
        host=${host%.conf}
        if [ "${thisnode}" != "${host}" ] ; then
            if traceroute6 -q 2 -w 2 -m ${hops} ${host}.${domain} 2> /dev/null | grep ${host}.${domain} 1> /dev/null ; then
                # we can reach it, add it to the peers file
                echo "${host}.${domain}" >> ${peersfile}
            fi  
        fi
    done
}

domain=`cat /etc/conf.d/domainname`
thisnode=`cat /etc/conf.d/hostname`
peersfile="/tmp/cfpeers"
lostfile="/tmp/nopeers"
networkdir="/etc/network.d"

case $1 in
     show_peers)
         # debug
         #logger "$0 $@"

         # show available peers
         if [ -f ${peersfile} ] ; then
             echo `cat ${peersfile}`
         else
             echo ""
         fi
         ;;
     calc_peers)
         # debug
         #logger "$0 $@"

         # calculate and show available peers
         calc_peers
         echo `cat ${peersfile}`
         ;;
     has_peers)
         # debug
         #logger "$0 $@"

         if [ -f ${peersfile} ] && [ -n "`cat ${peersfile}`" ] ; then
             # we have peers
             # remove an eventually existing lostfile
             if [ -f ${lostfile} ] ; then
                 rm -f ${lostfile}
             fi
             exit 0
         else
             # we don't have peers
             # trigger the lost node state
             if [ -f ${lostfile} ] ; then
                 # when we have no peers in the GLOBAL_LOSTTIMEOUT hours
                 # reset the node to a sane state and reboot it.
                 now=`date -u '+%s'`
                 lostsince=` date -u '+%s' -r ${lostfile}`
                 let elapsed=now-lostsince
                 let timeout=GLOBAL_LOSTTIMEOUT*3600
                 if [ ${elapsed} -gt ${timeout} ] ; then 
                     /var/cfengine/bin/lostnode.sh
                 fi
             else
                 touch ${lostfile}
             fi           
             exit 1
         fi 
         ;;
     *)
         echo "Usage: $0 calc_peers|show_peers|has_peers"
         exit 1
         ;;
esac

