#!/bin/sh

########################################################################
# Copyright (C) 2007-2009 Daniel Balsiger <mail<at>danielbalsiger.ch>  #
#                                                                      #
# This project evolved while my information science project and my     #
# master thesis that followed on.                                      #
#                                                                      #
# Check for latest versions at:                                        #
# https://subversion.cnds.unibe.ch/svn/adam/trunk/image-builder        #
#                                                                      #
# This program is free software; you can redistribute it and/or modify #
# it under the terms of the GNU General Public License version 2 as    #
# published by the Free Software Foundation.                           #
#                                                                      #
# Modification to guarantee regulation settings by Thomas Staub 2009   #
#                                                                      #
########################################################################


# when no peers were found in a defined number of hours
# this script resets all wireless values of the nodes to sane states
# (ESSID, TXPOWER and MODE of the config wireless device) 
# and reboots the node afterwords.

. /etc/init.d/rc.functions
. /etc/conf.d/rc.conf

# check which is the cf_device
for wifi in ${GLOBAL_WIFI_DEVICES} ; do
    if ip link show dev ${wifi} | grep ${GLOBAL_CFNET_MAC} >/dev/null ; then
        cf_device=${wifi}
        break
    fi
done

# we need a cf_device !!!!
if [ -z ${cf_device} ] ; then
    logecho "WARNING: no wireless device with MAC ${GLOBAL_CFNET_MAC} found, using ath0 by default."
    cf_device="ath0"
fi

# firstly check if ${cf_device} has the right essid even if it is not
# configured. else we could loose connection to the configuration network.
if [ "`get_var ${cf_device} ESSID`" != "${GLOBAL_CFNET_PREFIX}" ] ; then
    write_val ${cf_device}_ESSID /etc/conf.d/network.conf ${GLOBAL_CFNET_PREFIX}
fi

# clear the TXPOWER settings
max_legal_txpower=`get_var ${cf_device} MAX_LEGAL_TXPOWER`
if [ -n "${max_legal_txpower}" ] ; then
	write_val ${cf_device}_TXPOWER /etc/conf.d/network.conf ${max_legal_txpower}mW
then
	write_val ${cf_device}_TXPOWER /etc/conf.d/network.conf auto
fi

# clear the STANDARD settings (TOM: Removed STANDARD reset ... to be fixed)
# write_val ${cf_device}_STANDARD /etc/conf.d/network.conf g

# copy back to other nodes
cp /etc/conf.d/network.conf /etc/network.d/`cat /etc/conf.d/hostname`.conf

# copy to config image for next reboot
mount /mnt/config
cp /etc/conf.d/network.conf /mnt/config/etc/network.d/`cat /etc/conf.d/hostname`.conf
cp /etc/conf.d/network.conf /mnt/config/etc/conf.d/network.conf
umount /mnt/config

# reboot the node
/sbin/reboot


