#!/bin/sh

ALL_NODES="18 20 21"
CURRENT="0.3.99.7"
IMG_PATH="/home/stefan/projects/msc/local/images/"
SRC_PATH="/home/stefan/projects/msc/svn-rvs/adam/branches/visuc/image-builder"

help() {
	echo "USAGE: $0 [command] [options]"
	echo
	echo "Commands:"
	echo "  build-sys              Build an updated node image"
	echo "  deploy-sys [nodes]     Deploy image to all nodes or [nodes]"
	echo "  create-cfg [nodes]     Create config for all nodes or [nodes]"
	echo "  update-cfg [nodes]     Update config for all nodes or [nodes]"
	echo "  deploy-cfg [nodes]     Deploy config to all nodes or [nodes]"
}

create_cfg() {
	node="meshnode${1}" &&
	echo "Creating config image for ${node}" &&
	sudo ./image-tool gen_config alix ${node} &&
	mv config-${node}.default ${IMG_PATH}/config/ &&
	update_config "${1}"
}

update_config() {
	node="meshnode${1}"
	echo "Injecting net config into config image for ${node}"

	cfg=$( readlink -f ${IMG_PATH}/../node-config.tar.gz ) &&
	img="${IMG_PATH}/config/config-${node}.default" &&

	cd ${SRC_PATH} &&
	sudo ./image-tool inject_config ${cfg} ${img}
}

build_sys() {
	echo "Building ovis image ${CURRENT}"
	cd ${SRC_PATH} &&
	sudo ./image-tool gen_image alix ovis-${CURRENT} &&
	mv alix-image-ovis-${CURRENT}.bin.gz ${IMG_PATH}/nodes/ &&
	stat ${IMG_PATH}/nodes/alix-image-ovis-${CURRENT}.bin.gz
}

case "$1" in
	build-sys)
		build_sys
		;;
	create-cfg)
		if [ ! -z "$2" ] ; then
			nodes="$2"
		else
			nodes="${ALL_NODES}"
		fi

		for node in ${nodes} ; do
			create_cfg ${node}
		done
		;;
	update-cfg)
		if [ ! -z "$2" ] ; then
			nodes="$2"
		else
			nodes="${ALL_NODES}"
		fi

		for node in ${nodes} ; do
			update_config ${node}
		done
		;;
	deploy-sys)
		if [ ! -z "$2" ] ; then
			nodes="$2"
		else
			nodes="${ALL_NODES}"
		fi

		for node in ${nodes} ; do
			hostname="meshnode${node}"
			img_name="alix-image-ovis-${CURRENT}.bin.gz"
			nfiles=$( ssh root@${hostname} ls /boot | wc -l )

			while [ ${nfiles} -eq 0 ] ; do
				echo "Please mount /boot on ${hostname}"
				read
				nfiles=$( ssh root@${hostname} ls /boot|wc -l )
			done

			scp ${IMG_PATH}/nodes/${img_name} \
				root@${hostname}:/boot/
		done

		;;
	deploy-cfg)
		if [ ! -z "$2" ] ; then
			nodes="$2"
		else
			nodes="${ALL_NODES}"
		fi

		for node in ${nodes} ; do
			node="meshnode${node}" &&
			dest="/mnt/state/config/config.default" &&
			img="${IMG_PATH}/config/config-${node}.default" &&
			scp ${img} root@${node}:${dest}
		done
		;;
	*)
		help
		;;
esac
